==> demoniac-0.3.tar.gz: demoniac-0.3/libfx/fxinstance.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * fxinstance.h: Effect Instance class for DemoNiac
 * Leto/calodox, 18.3.2001
 */

#ifndef _FXINSTANCE_H_
#define _FXINSTANCE_H_

#include <vector>
#include <fx.h>
#include "glmain.h"
#include "saver.h"
#include "loader.h"
#include "dlgopt.h"
#include "genericoption.h"

#define MAX_FXINSTANCE_NAME_LENGTH 256

using namespace std;

class FXInstance {
private:
	bool fxInitialized;	// true if the fx is initialized & ready to render.

	int initTime;
	int startTime;
	int stopTime;

public:
	FXGeneric *fx;
	vector<GenericOption *> opts;
	char name[MAX_FXINSTANCE_NAME_LENGTH];		// instance name
	DlgOpt *dlg;		// instance option dialog

	GtkWidget *treeItem; // used by TrackDlg

	// constructor
	FXInstance(FXGeneric *fx);
	FXInstance(Loader *l, vector<FXGeneric *> vfx);

	// destructor
	~FXInstance();

	// saver
	void save(Saver *s);
	
	void init();	// initialized effect
	void finish();	// finish effect
	void render();	// render effect

	// do what should be done at time
	void actionAtTime(int time);
	bool FXInstance::isActive(int time);

	void setInitTime(int time);
	void setStartTime(int time);
	void setStopTime(int time);

	int getInitTime() { return initTime; }
	int getStartTime() { return startTime; }
	int getStopTime() { return stopTime; }
	
};

// for registering options, remember what instance we're talking about
extern FXInstance *currentFX; 

#endif

==> demoniac-0.4.tar.gz: demoniac-0.4/libfx/fxinstance.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * fxinstance.h: Effect Instance class for DemoNiac
 * Leto/calodox, 18.3.2001
 */

#ifndef _FXINSTANCE_H_
#define _FXINSTANCE_H_

#include <vector>
#include <fx.h>
#include "glmain.h"
#include "saver.h"
#include "loader.h"
#include "dlgopt.h"
#include "genericoption.h"
#include "duration.h"

using namespace std;

class FXInstance : public Duration {
private:
	bool fxInitialized;	// true if the fx is initialized & ready to render.

public:
	FXGeneric *fx;
	vector<GenericOption *> opts;

	DlgOpt *dlg;		// instance option dialog

	// constructor
	FXInstance(FXGeneric *fx);
	FXInstance(Loader *l, vector<FXGeneric *> vfx);

	// destructor
	~FXInstance();

	// saver
	void save(Saver *s);
	
	void init();	// initialized effect
	void finish();	// finish effect
	void render();	// render effect

	virtual void setTime(int time);
	// do what should be done at time
	virtual void actionAtTime(int time);
	bool isActive(int time);

};

// for registering options, remember what instance we're talking about
extern FXInstance *currentFX; 

#endif
